@@ -12,7 +12,7 @@ package Geo::Coder::Googlev3;
 
 use strict;
 use vars qw($VERSION);
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Carp            ('croak');
 use Encode          ();
@@ -42,6 +42,7 @@ sub ua {
 sub geocode {
     my($self, %args) = @_;
     my $loc = $args{location};
+    my $raw = $args{raw};
     my $ua = $self->ua;
     my $url = URI->new('http://maps.google.com/maps/api/geocode/json');
     my %url_params;
@@ -57,12 +58,17 @@ sub geocode {
     if ($resp->is_success) {
 	my $content = $resp->decoded_content(charset => "none");
 	my $res = JSON::XS->new->utf8->decode($content);
+        if ($raw) {
+            return $res;
+        }
 	if ($res->{status} eq 'OK') {
             if (wantarray) {
                 return @{ $res->{results} };
             } else {
                 return $res->{results}->[0];
             }
+        } elsif ($res->{status} eq 'ZERO_RESULTS') {
+            return;
 	} else {
 	    croak "Fetching $url did not return OK status, but '" . $res->{status} . "'";
 	}
@@ -225,6 +231,12 @@ The returned data structure looks like this:
     }
   };
 
+The B<raw> option may be set to a true value to get the uninterpreted,
+raw result from the API. Just the JSON data will be translated into a
+perl hash.
+
+    $raw_result = $geocoder->geocode(location => $location, raw => 1);
+
 =back  
 
 =head1 AUTHOR
@@ -236,7 +248,7 @@ it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Geo::Coder::Google>.
+L<Geo::Coder::Google>, L<Geo::Coder::Many>.
 
 =cut
 
